#ifndef _ISO15765_3_H
#define _ISO15765_3_H

/*----------------------------- includes ---------------------------------*/

#include "Std_Types.h"
#include "DiagnosticL/Comp_ISO_15765_2/TP.h"
#include "DiagnosticL/UDS/Iso15765_layer3/Iso15765_3_CFG.h"
#include "DiagnosticL/Comp_HAL_Autosar_Wrappers/Timer.h"

/*----------------------------- defines ----------------------------------*/

/* Mascara de bits d'obtencio de la subfuncio  */
#define UDS_SUBFUNCTION_MASK		((UI_8)0x7F)

/* Positive Reponse Calculation Code */
#define UDS_POS_RESP_CODE ((UI_8)0x40)    

/* Negative Response Code and Size */
#define UDS_NEG_RESP_CODE ((UI_8)0x7F)    
#define UDS_NEG_RESP_SIZE ((UI_16)0x03) 

/* UDS Session Identifiers */
#define UDS_DEFAULT_SESSION                     ((UI_8)0x01)
#define UDS_PROGRAMMING_SESSION                 ((UI_8)0x02)
#define UDS_EXT_DIAG_SESSION 	                ((UI_8)0x03)
//#define UDS_SAFETY_SYSTEM_DIAGNOSTIC_SESSION    ((UI_8)0x04) NOT IMPLEMENTED YET
/* UDS Session Identifiers Mask */
#define UDS_DEFAULT_SESSION_MASK                    ((UI_8)0x01)
#define UDS_PROGRAMMING_SESSION_MASK                ((UI_8)0x02)
#define UDS_EXT_DIAG_SESSION_MASK 	                ((UI_8)0x04)
//#define UDS_SAFETY_SYSTEM_DIAGNOSTIC_SESSION_MASK   ((UI_8)0x08) NOT IMPLEMENTED YET
#define UDS_SYSTEM_SUPPLIER_SPECIFIC_SESSION_MASK   ((UI_8)0x10)
#define UDS_ALL_SESSION_MASK                        ((UI_8)0xFF)
#define UDS_DEFAULT_VALUE_SESSION_MASK              ((UI_8)0x00)


#if ((ISO15765_3_VARIANT == ISO15765_3_UDS)||(ISO15765_3_VARIANT == ISO15765_3_FIAT)||(ISO15765_3_VARIANT == ISO15765_3_UDS_ONLY_SF)||(ISO15765_3_VARIANT == ISO15765_3_GAC))
/* LIN Services Identifiers	*/
#define LIN_ASSIGN_FRAME_IDENTIFIER						((UI_8)0xB1)
#define LIN_ASSIGN_FRAME_IDENTIFIER_RANGE				((UI_8)0xB7)
#define LIN_READ_BY_IDENTIFIER							((UI_8)0xB2)
#define LIN_ASSIGN_NAD									((UI_8)0xB0)
#define LIN_CONDITIONAL_CHANGE_NAD						((UI_8)0xB3)

/* UDS Services Identifiers */
#define UDS_DIAGNOSTIC_SESSION_CONTROL                  ((UI_8)0x10)
#define UDS_ECU_RESET                                   ((UI_8)0x11)
#define UDS_CLEAR_DIAGNOSTIC_INFORMATION                ((UI_8)0x14)
#define UDS_READ_DTC_INFORMATION                        ((UI_8)0x19)
#define UDS_READ_DATA_BY_IDENTIFIER                     ((UI_8)0x22)
#define UDS_READ_MEMORY_BY_ADDRESS                      ((UI_8)0x23)
#define UDS_READ_SCALING_DATA_BY_IDENTIFIER             ((UI_8)0x24)
#define UDS_SECURITY_ACCESS                             ((UI_8)0x27)
#define UDS_COMMUNICATION_CONTROL                       ((UI_8)0x28)
#define UDS_READ_DATA_BY_PERIODIC_IDENTIFIER            ((UI_8)0x2A)
#define UDS_DYNAMICALLY_DEFINE_DATA_IDENTIFIER          ((UI_8)0x2C)
#define UDS_WRITE_DATA_BY_IDENTIFIER                    ((UI_8)0x2E)
#define UDS_INPUT_OUTPUT_CONTROL_BY_ID                  ((UI_8)0x2F)
#define UDS_CONTROL_ROUTINE                             ((UI_8)0x31)
#define UDS_REQUEST_DOWNLOAD                            ((UI_8)0x34)
#define UDS_REQUEST_UPLOAD                              ((UI_8)0x35)
#define UDS_TRANSFER_DATA                               ((UI_8)0x36)
#define UDS_REQUEST_TRANSFER_EXIT                       ((UI_8)0x37)
#define UDS_WRITE_MEMORY_BY_ADDRESS                     ((UI_8)0x3D)
#define UDS_TESTER_PRESENT                              ((UI_8)0x3E)
#define UDS_ACCES_TIMING_PARAMETER                      ((UI_8)0x83)
#define UDS_SECURE_DATA_TRANSMISSION                    ((UI_8)0x84)
#define UDS_CONTROL_DTC_SETTING                         ((UI_8)0x85)
#define UDS_RESPONSE_ON_EVENT                           ((UI_8)0x86)
#define UDS_LINK_CONTROL                                ((UI_8)0x87)
#elif (ISO15765_3_VARIANT == ISO15765_3_RSA)
/* RSA Services Identifiers */
#define RSA_START_ROUTINE_BY_LOCAL_ID               ((UI_8)0x31)
#define RSA_STOP_ROUTINE_BY_LOCAL_ID                ((UI_8)0x32)
#define RSA_READ_DATA_BY_LOCAL_ID                   ((UI_8)0x21)
#define RSA_REQUEST_UPLOAD                          ((UI_8)0x35)
#define RSA_WRITE_DATA_BY_LOCAL_ID                  ((UI_8)0x3B)
#define RSA_INPUT_OUTPUT_CONTROL_BY_LOCAL_ID        ((UI_8)0x30)
#define RSA_READ_DATA_BY_IDENTIFIER                 ((UI_8)0x22)
#define RSA_REQUEST_DOWNLOAD                        ((UI_8)0x34)
#endif

/* Iso15765_3SendResponse Valid Response Identifiers */
#define ISO15765_3_POSITIVE_RESPONSE                        ((UI_8)0x01)
#define UDS_ERR_GENERAL_REJECT	                            ((UI_8)0x10)
#define UDS_ERR_SERVICE_NOT_SUPPORTED                       ((UI_8)0x11)
#define UDS_ERR_SUBFUNCTION_NOT_SUPPORTED                   ((UI_8)0x12)
#define UDS_ERR_INVALID_FORMAT                              ((UI_8)0x13)
#define UDS_ERR_BUSY_REPEAT_REQUEST                         ((UI_8)0x21)
#define UDS_ERR_CONDITIONS_NOT_CORRECT                      ((UI_8)0x22)
#define UDS_ERR_ROUTINE_NOT_COMPLETE                        ((UI_8)0x23)
#define UDS_ERR_REQUEST_SEQUENCE_ERROR                      ((UI_8)0x24)
#define UDS_ERR_REQUEST_OUT_OF_RANGE                        ((UI_8)0x31)
#define UDS_ERR_SECURITY_ACCESS_DENIED                      ((UI_8)0x33)
#define UDS_ERR_INVALID_KEY                                 ((UI_8)0x35)
#define UDS_ERR_EXCEEDED_NUMBER_OF_ATTEMPTS                 ((UI_8)0x36)
#define UDS_ERR_REQUIRED_TIME_DELAY_NOT_EXPIRED             ((UI_8)0x37)
#define UDS_ERR_UPLOAD_DOWNLOAD_NOT_ACCEPTED                ((UI_8)0x70)
#define UDS_ERR_TRANSFER_SUSPENDED                          ((UI_8)0x71)
#define UDS_ERR_GENERAL_PROGRAMMING_FAILURE                 ((UI_8)0x72)
#define UDS_ERR_WRONG_BLOCK_SEQUENCE                        ((UI_8)0x73)
#define UDS_ERR_RESPONSE_PENDING                            ((UI_8)0x78)
#define UDS_ERR_SUBFUNCTION_NOT_SUPORTED_IN_ACTIVE_SESSION  ((UI_8)0x7E)
#define UDS_ERR_SERVICE_NOT_SUPORTED_IN_ACTIVE_SESSION      ((UI_8)0x7F)

/* Session Control Defines */
#define UDS_DEFAULT_SESSION ((UI_8)0x01)

/* Multidevice defines */
#define DEVICE_0	((UI_8)0x00)
#define DEVICE_1	((UI_8)0x01)
#define DEVICE_2	((UI_8)0x02)
#define DEVICE_3	((UI_8)0x03)
typedef UI_8 t_device_addressed;

#define UDS_REQUEST_DOWNLOAD_ERROR_INVALID_DEVICE       ((UI_8)0x00)
#define UDS_REQUEST_DOWNLOAD_ERROR_INCOMPATIBLE_TYPE    ((UI_8)0x01)
#define UDS_REQUEST_DOWNLOAD_ERROR_ECU_LOCKED           ((UI_8)0x02)

#define UDS_TRANSFER_DATA_ERROR_INVALID_BLOCK       ((UI_8)0x00)
#define UDS_TRANSFER_DATA_ERROR_OUT_OF_RANGE        ((UI_8)0x01)


/* Download Status Defines */
#define DOWNLOAD_STATUS_IDLE			((UI_8)0x00)
#define DOWNLOAD_STATUS_ONGOING			((UI_8)0x01)
#define DOWNLOAD_STATUS_FINISHED_OK		((UI_8)0x02)
#define DOWNLOAD_STATUS_FINISHED_NOK	((UI_8)0x03)
typedef UI_8 t_download_status;

/* Routine Control Types */
#define UDS_START_ROUTINE           ((UI_8)0x01)
#define UDS_STOP_ROUTINE            ((UI_8)0x02)
#define UDS_REQUEST_ROUTINE_RESULTS ((UI_8)0x03)

/* Download Address Size */
#define ISO3_16BIT_ADDRESS	(1)
#define ISO3_32BIT_ADDRESS	(2)

/* MASKS FOR STATUS PROGRAMMING */
#define SETPROGRAMMING_STATUS_ECU_STATUS_VALID          ((UI_32)0xFFFFFFFFU)
#define SETPROGRAMMING_STATUS_ECU_STATUS_NO_VALID       ((UI_32)0xF9FFFFFFU)
#define SETPROGRAMMING_STATUS_DOWNLOAD_INCM_TYPE        ((UI_32)0xF9FFBFFFU)
#define SETPROGRAMMING_STATUS_DOWNLOAD_INCM_AREA        ((UI_32)0xF9FFDFFFU)
#define SETPROGRAMMING_STATUS_DOWNLOAD_INCM_SIZE        ((UI_32)0xF9FF7FFFU)
#define SETPROGRAMMING_STATUS_WRONG_SECURITY_ACCESS     ((UI_32)0xFFFFEFFFU)
#define SETPROGRAMMING_STATUS_TRANS_INCML_SIZE          ((UI_32)0xF9FDFFFFU)
#define SETPROGRAMMING_STATUS_CHK_INCM_AREA             ((UI_32)0xF9DFFFFFU)
#define SETPROGRAMMING_STATUS_CHK_INCM_SIZE             ((UI_32)0xF9BFFFFFU)
#define SETPROGRAMMING_STATUS_WRONG_CHK                 ((UI_32)0xF97FFFFFU)
#define SETPROGRAMMING_STATUS_ERA_WR_ADDRR              ((UI_32)0xF9EFFFFFU)
#define SETPROGRAMMING_STATUS_ERA_WR_SIZE               ((UI_32)0xF9F7FFFFU)

#define SETPROGRAMMING_STATUS_SEQ_TRANS                 ((UI_32)0xF9FEFFFFU)
#define SETPROGRAMMING_STATUS_SEQ_ERASE                 ((UI_32)0xF9FFFDFFU)
#define SETPROGRAMMING_STATUS_SEQ_WRDID                 ((UI_32)0xFFFFFEFFU)
#define SETPROGRAMMING_STATUS_SEQ_CHCKSUM               ((UI_32)0xF9FFF7FFU)
#define SETPROGRAMMING_STATUS_HW_SW_INCMPL              ((UI_32)0xF9FFFFFEU) //Return 0x13
#define SETPROGRAMMING_STATUS_SW_RELEASE_INCMPL         ((UI_32)0xF9FFFFFDU) //Return 0x70

/* EcuReset Subfunctions According to ISO15765_3 */
#define UDS_HARD_RESET                    ((UI_8)0x01)
#define UDS_KEY_ON_OFF_RESET              ((UI_8)0x02)
#define UDS_SOFT_RESET                    ((UI_8)0x03)
#define UDS_ENABLE_RAPID_POWER_SHUT_DOWN  ((UI_8)0x04)
#define UDS_DISABLE_RAPID_POWER_SHUT_DOWN ((UI_8)0x05)

/* Security Levels  */
#define UDS_ECU_LOCKED          ((UI_8)0)
#define UDS_ECU_UNLOCKED_LEVEL1 ((UI_8)1)

/* Control routine subfunctions */
#define UDS_CTRL_ROUTINE_START      ((UI_8)0x01)
#define UDS_CTRL_ROUTINE_STOP       ((UI_8)0x02)
#define UDS_CTRL_ROUTINE_RESULTS    ((UI_8)0x03)

/* DTCs */
/* DTCs CONTROL SETTINGS */
#define UDS_DTCS_ON     ((UI_8)0x01)
#define UDS_DTCS_OFF    ((UI_8)0x02)
/* DTCs PARAMETER SUBFUNCTION */
#define REPORT_NUMBER_OF_DTC_BY_STATUS_MASK                         ((UI_8)0x01)
#define REPORT_DTC_BY_STATUS_MASK                                   ((UI_8)0x02)
#define REPORT_DTC_SNAPSHOT_IDENTIFICATION                          ((UI_8)0x03)
#define REPORT_DTC_SNAPSHOT_RECORD_BY_DTC_NUMBER                    ((UI_8)0x04)
#define REPORT_DTC_SNAPSHOT_RECORD_BY_RECORD_NUMBER                 ((UI_8)0x05)
#define REPORT_DTC_EXTENDED_DATA_RECORD_BY_DTC_NUMBER               ((UI_8)0x06)
#define REPORT_NUMBER_OF_DTC_BY_SEVERITY_MASK_RECORD                ((UI_8)0x07)
#define REPORT_DTC_BY_SEVERITY_MASK_RECORD                          ((UI_8)0x08)
#define REPORT_SEVERITY_INFORMATION_OF_DTC                          ((UI_8)0x09)
#define REPORT_SUPPORTED_DTC                                        ((UI_8)0x0A)
#define REPORT_FIRST_TEST_FAILED_DTC                                ((UI_8)0x0B)
#define REPORT_FIRST_CONFIRMED_DTC                                  ((UI_8)0x0C)
#define REPORT_MOST_RECENT_TEST_FAILED_DTC                          ((UI_8)0x0D)
#define REPORT_MOST_RECENT_CONFIRMED_DTC                            ((UI_8)0x0E)
#define REPORT_MIRROR_MEMORY_DTC_BY_STATUS_MASK                     ((UI_8)0x0F)
#define REPORT_MIRROR_MEMORY_DTC_EXTENDED_DATA_RECORD_BY_DTC_NUMBER ((UI_8)0x10)
#define REPORT_NUMBER_OF_MIRROR_MEMORY_DTC_BY_STATUS_MASK           ((UI_8)0x11)
#define REPORT_NUMBER_OF_EMISSIONS_RELATED_OBD_DTC_BY_STATUS_MASK   ((UI_8)0x12)
#define REPORT_EMISSIONS_RELATED_OBD_DTC_BY_STATUS_MASK             ((UI_8)0x13)
#define REPORT_DTC_FAULT_DETECTION_COUNTER                          ((UI_8)0x14)
#define REPORT_DTC_WITH_PERMANENT_STATUS                            ((UI_8)0x15)
/* DTC STATUS MASK */
#define DTC_TEST_FAILED_MASK                                ((UI_8)0x01)
#define DTC_TEST_FAILED_THIS_MONITORING_CYCLE_MASK          ((UI_8)0x02)
#define DTC_PENDING_MASK                                    ((UI_8)0x04)
#define DTC_CONFIRMED_MASK                                  ((UI_8)0x08)
#define DTC_TEST_NOT_COMPLETED_SINCE_LAST_CLEAR_MASK        ((UI_8)0x10)
#define DTC_TEST_FAILED_SINCE_LAST_CLEAR_MASK               ((UI_8)0x20)
#define DTC_TEST_NOT_COMPLETED_THIS_MONITORING_CYCLE_MASK   ((UI_8)0x40)
#define DTC_TEST_WARNING_INDICATOR_REQUESTED_MASK           ((UI_8)0x80)



/* COMMUNICATION CONTROL */
/* COMMUNICATION CONTROL SUBFUNCTIONS */
#define UDS_ENABLE_RX_AND_TX            ((UI_8)0x00)
#define UDS_ENABLE_RX_AND_DISABLE_TX    ((UI_8)0x01)
#define UDS_DISABLE_RX_AND_DISABLE_TX   ((UI_8)0x03)
/* COMMUNICATION CONTROL COMMUNICATION TYPE */
#define UDS_NORMAL_COMM_MESSAGES        ((UI_8)0x01)
#define UDS_NETWORK_MNG_COMM_MESSAGES   ((UI_8)0x02)
#define UDS_DIAG_COMM_MESSAGES          ((UI_8)0x04)


/*-------------------------- Data Types ----------------------------------*/

#if (DOWNLOAD_ADDRESS_SIZE == ISO3_16BIT_ADDRESS)
typedef UI_16 t_iso3_addr;
#elif (DOWNLOAD_ADDRESS_SIZE == ISO3_32BIT_ADDRESS)
typedef UI_32 t_iso3_addr;
#else
	#error "Set the ISO3 Address Size"
#endif

typedef enum {
	ISO15765_3_FUN_REQUEST = 0,
	ISO15765_3_PHY_REQUEST = 1
} t_iso15765_3_req_mode;

/* Tipus de dades adecuat per la resposta positiva a la peticio de    */
/* cada un dels serveis                                               */
/* Nomes es poden fer servir UI_8 perque l'endianes i l'alineament de */
/* les dades a memoria pot variar entre plataformes                   */


#if ((ISO15765_3_VARIANT == ISO15765_3_UDS) || (ISO15765_3_VARIANT == ISO15765_3_FIAT) || (ISO15765_3_VARIANT == ISO15765_3_UDS_ONLY_SF))
/**********************************************************************
| Service: LIN_READ_BY_IDENTIFIER
|----------------------------------------------------------------------
| Case ID==0: LIN Product ID
| 	Parameters:
|   	supplierId_L: LSB of LIN Supplier ID
|   	supplierId_H: MSB of LIN Supplier ID
|   	functionId_L: LSB of LIN Function ID
|   	functionId_H: MSB of LIN Function ID
|   	variant: variant version of the product
|----------------------------------------------------------------------
| Size: 5
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 supplierId_L;
	UI_8 supplierId_H;
	UI_8 functionId_L;
	UI_8 functionId_H;
	UI_8 variant;
} * tp_lin_read_by_id_0_resp;

/**********************************************************************
| Service: LIN_READ_BY_IDENTIFIER
|----------------------------------------------------------------------
| Case ID==1: Serial number
| 	Parameters:
|   	serial_0: LSB of Serial Number
|   	serial_1: Serial Number part 2
|   	serial_2: Serial Number part 3
|   	serial_3: MSB of of Serial Number
|----------------------------------------------------------------------
| Size: 4
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 serial_0;
	UI_8 serial_1;
	UI_8 serial_2;
	UI_8 serial_3;
} * tp_lin_read_by_id_1_resp;

/**********************************************************************
| Service: LIN_READ_BY_IDENTIFIER
|----------------------------------------------------------------------
| Case ID>=16 && ID<=31: MessageID
| 	Parameters:
|   	messageID_LSB: LSB of requested message id
|   	messageID_MSB: MSB of requested message id
|   	protectedID: protectedID
|----------------------------------------------------------------------
| Size: 3
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 messageID_LSB;
	UI_8 messageID_MSB;
	UI_8 protectedID;
} * tp_lin_read_by_id_2_resp;

/**********************************************************************
| Service: LIN_READ_BY_IDENTIFIER
|----------------------------------------------------------------------
| Case ID==32-63: User defined
| 	Parameters:
|   	user_def_0: user defined parameter
|   	user_def_1: user defined parameter
|   	user_def_2: user defined parameter
|   	user_def_3: user defined parameter
|   	user_def_4: user defined parameter
|----------------------------------------------------------------------
| Size: 5
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 user_def_0;
	UI_8 user_def_1;
	UI_8 user_def_2;
	UI_8 user_def_3;
	UI_8 user_def_4;
} * tp_lin_read_by_id_userdef_resp;

/**********************************************************************
| Servei:  Diagnostic Session Control
|----------------------------------------------------------------------
| Explicacio dels parametres:
|   ctrl_type: echo of the subfunction parameter from the request message
|----------------------------------------------------------------------
| Mida: 5
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 ctrl_type;
} * tp_uds_communication_control_resp;

/**********************************************************************
| Servei:  Diagnostic Session Control
|----------------------------------------------------------------------
| Explicacio dels parametres:
|   diagnostic_session: Ha de ser el mateix valor que s'ha passat
|                       com a parametre en la peticio del servei
|   p2_high: MSB del valor del P2 que es pot oferir durant la nova sessio
|   p2_low: LSB del valor del P2 que es pot oferir durant la nova sessio
|   p2_high: MSB del valor del P2 extended que es pot oferir durant
|            la nova sessio
|   p2_high: MSB del valor del P2 extended que es pot oferir durant
|            la nova sessio
|----------------------------------------------------------------------
| Mida: 5
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 diagnostic_session;
	UI_8 p2_high;
	UI_8 p2_low;
	UI_8 p2_ext_high;
	UI_8 p2_ext_low;
} * tp_uds_diagnostic_session_control_resp;

/**********************************************************************
| Servei:  Ecu Reset
|----------------------------------------------------------------------
| Explicacio dels parametres:
|   reset_mode: Ha de ser el mateix valor que s'ha passat
|               com a parametre en la peticio del servei
|----------------------------------------------------------------------
| Mida: 1
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 reset_mode;
} * tp_uds_ecu_reset_resp;

/**********************************************************************
| Servei:  Tester Present
|----------------------------------------------------------------------
| Explicacio dels parametres:
|   zero: Ha de ser 0
|----------------------------------------------------------------------
| Mida: 1
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 zero;
} * tp_uds_tester_present_resp;

/**********************************************************************
| Servei:  Read Memory By Address
|----------------------------------------------------------------------
| Explicacio dels parametres:
|   buffer_dades: Buffer per les dades demanades
|----------------------------------------------------------------------
| Mida: mida buffer_dades
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 buffer_dades[(TP_DIAG_TX_LEN - (UI_8)1)];
} * tp_uds_read_memory_by_address_resp;

/**********************************************************************
| Servei:  Security Access Seed
|----------------------------------------------------------------------
| Explicacio dels parametres:
|   access_mode: El mateix access_mode que s'ha passat com a parametre
|                a la rutina d'atencio al servei
|   seed: La llavor calculada.
|----------------------------------------------------------------------
| Mida: 1 + mida seed
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 access_mode;
	UI_8 seed[(TP_DIAG_TX_LEN - (UI_8)2)];
} * tp_uds_security_access_seed_resp;

/**********************************************************************
| Servei:  Security Access Key
|----------------------------------------------------------------------
| Explicacio dels parametres:
|   access_mode: El mateix access_mode que s'ha passat com a parametre
|                a la rutina d'atencio al servei
|   security_access_status: ?? 0x34
|----------------------------------------------------------------------
| Mida: 2
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 access_mode;
} * tp_uds_security_access_key_resp;

/**********************************************************************
| Servei:  Write Data By Identifier
|----------------------------------------------------------------------
| Explicacio dels parametres:
|   id_high: MSB del id passat com a parametre a la rutina d'atencio
|            al servei.
|   id_low: LSB del id passat com a parametre a la rutina d'atencio
|           al servei.
|----------------------------------------------------------------------
| Mida: 2
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 id_high;
	UI_8 id_low;
} * tp_uds_write_data_by_identifier;

/**********************************************************************
| Servei:  Input Output Control By Identifier
|----------------------------------------------------------------------
| Explicacio dels parametres:
|   io_ctrl_data_id: 2 bytes passats com a parametre a la rutina
|                    d'atencio al servei.
|   io_ctrl_type: io_ctrl_param passat com a parametre a la rutina
|                 d'atencio al servei.
|   control_state: buffer amb informacio control option record +
|                  control enable mask.
|----------------------------------------------------------------------
| Mida:
/--------------------------------------------------------------------*/
typedef struct {
    UI_8 id_high;
    UI_8 id_low;
    UI_8 io_ctrl_type;
    UI_8 control_state[(TP_DIAG_TX_LEN - (UI_8)4)];
} * tp_uds_input_output_control_by_id;

/**********************************************************************
| Servei:  Control Rountine
|----------------------------------------------------------------------
| Explicacio dels parametres:
|   routine_ctrl_type: routine ctrl type passed during the service
|                      request
|   routine_id: routine_local_id passat com a parametre a la
|               rutina d'atencio al servei
|   routine_results: Buffer de dades amb el resultat
|----------------------------------------------------------------------
| Mida: 3 + mida routine_results
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 routine_ctrl_type;
	UI_8 routine_id_high;
	UI_8 routine_id_low;
	UI_8 routine_status[(TP_DIAG_TX_LEN - (UI_8)4)];
} * tp_uds_control_routine;

/**********************************************************************
| Servei:  Read Data By Local Identifier
|----------------------------------------------------------------------
| Explicacio dels parametres:
|   id_high: MSB del identificador de la informacio demanada passada
|            com a parametre a la rutina d'atencio al servei.
|   id_low: LSB del identificador de la informacio demanada passada
|           com a parametre a la rutina d'atencio al servei.
|   buffer_dades: Buffer per les dades d'identificacio demanades
|----------------------------------------------------------------------
| Mida: 1 + mida buffer_dades
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 buffer_dades[(TP_DIAG_TX_LEN - (UI_8)3)];
} * tp_uds_read_data_by_identifier_resp;


/**********************************************************************
| Servei:  Read DTC Information
|----------------------------------------------------------------------
| Explicacio dels parametres:
|   id_high: MSB del identificador de la informacio demanada passada
|            com a parametre a la rutina d'atencio al servei.
|   id_low: LSB del identificador de la informacio demanada passada
|           com a parametre a la rutina d'atencio al servei.
|   buffer_dades: Buffer per les dades d'identificacio demanades
|----------------------------------------------------------------------
| Mida: 1 + mida buffer_dades
/--------------------------------------------------------------------*/
typedef struct {
    UI_8 subservice;
    UI_8 buffer_dades[(TP_DIAG_TX_LEN - (UI_8)2)];
}* tp_uds_read_dtc_information_resp;

/**********************************************************************
| Servei:  Control DTC Setting
|----------------------------------------------------------------------
| Explicacio dels parametres:
|   buffer_dades: Buffer per les dades d'identificacio demanades
|----------------------------------------------------------------------
| Mida: 1 + mida buffer_dades
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 dtc_setting_type;
} * tp_uds_control_dtc_setting_resp;

/**********************************************************************
| Servei:  Request Download
|----------------------------------------------------------------------
| Explicacio dels parametres:
|   len_format_id: bit [7..4]: Length (number of bytes) of the
|                  max_num_of_block_len parameter.
|                  bit [3..0]: zero
|   max_num_of_block_len: mida del buffer de transferencia
|----------------------------------------------------------------------
| Mida: 1 + mida max_num_of_block_len
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 len_format_id;
	UI_8 max_num_of_block_len[(TP_DIAG_TX_LEN - (UI_8)2)];
} * tp_uds_request_download;

/**********************************************************************
| Servei:  Transfer data
|----------------------------------------------------------------------
| Explicacio dels parametres:
|   block_seq: Numero de sequencia de TranferData que s'ha passat en
|              la peticio del servei
|   data: Buffer de dades
|----------------------------------------------------------------------
| Mida: 1 + mida de data
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 block_seq;
	UI_8 data_buf[(TP_DIAG_TX_LEN - (UI_8)2)];
} * tp_uds_transfer_data;

/**********************************************************************
| Servei:  Request Transfer Exit
|----------------------------------------------------------------------
| Explicacio dels parametres:
|   data: Buffer de dades
|----------------------------------------------------------------------
| Mida: mida de data
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 data_buf[(TP_DIAG_TX_LEN - (UI_8)1)];
} * tp_uds_request_transfer_exit;

/**********************************************************************
| Servei:  Write Memory By Address
|----------------------------------------------------------------------
| Explicacio dels parametres:
|----------------------------------------------------------------------
| Mida: 1 + mida buffer_dades
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 addr_data_length_id;
	UI_8 buffer_dades[(TP_DIAG_TX_LEN - (UI_8)2)];
} * tp_uds_write_memory_by_address;


#elif (ISO15765_3_VARIANT == ISO15765_3_RSA)
/**********************************************************************
| Servei:  Start Routine By Local Id de RSA
|----------------------------------------------------------------------
| Explicacio dels parametres:
|   routine_id: identifier of the routine to start
|   routine_params:
|----------------------------------------------------------------------
| Mida: 2 + mida routine_params
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 routine_id;
	UI_8 routine_status;
	UI_8 routine_params[(TP_DIAG_TX_LEN - (UI_8)3)];
} * tp_rsa_start_routine_by_local_id;

/**********************************************************************
| Servei: ReadDataByLocalId de RSA
|----------------------------------------------------------------------
| Explicacio dels parametres:
|----------------------------------------------------------------------
| Mida: 1 + mida data
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 read_id;
	UI_8 data_buf[(TP_DIAG_TX_LEN - (UI_8)2)];
} * tp_rsa_read_data_by_local_id;

/**********************************************************************
| Servei:  StopRoutineByLocalId de RSA
|----------------------------------------------------------------------
| Explicacio dels parametres:
|----------------------------------------------------------------------
| Mida: 2 + mida routine_results
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 routine_id;
	UI_8 routine_status;
	UI_8 routine_params[(TP_DIAG_TX_LEN - (UI_8)3)];
} * tp_rsa_stop_routine_by_local_id;

/**********************************************************************
| Servei:  RequestUpload de RSA
|----------------------------------------------------------------------
| Explicacio dels parametres:
|----------------------------------------------------------------------
| Mida: mida de upload_resp
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 upload_resp[(TP_DIAG_TX_LEN - (UI_8)1)];
} * tp_rsa_request_upload;

/**********************************************************************
| Servei:  WriteDataByLocalId de RSA
|----------------------------------------------------------------------
| Explicacio dels parametres:
|----------------------------------------------------------------------
| Mida: 1
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 write_id;
} * tp_rsa_write_data_by_local_id;

/**********************************************************************
| Servei:  InputOutputControlByLocalId de RSA
|----------------------------------------------------------------------
| Explicacio dels parametres:
|----------------------------------------------------------------------
| Mida: 2 + mida de data
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 input_output_id;
	UI_8 control_status;
	UI_8 data_buf[(TP_DIAG_TX_LEN - (UI_8)3)];
} * tp_rsa_input_output_control_by_local_id;

/**********************************************************************
| Servei:  ReadDataByIdentifier de RSA
|----------------------------------------------------------------------
| Explicacio dels parametres:
|----------------------------------------------------------------------
| Mida: mida de id_with_data
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 id_with_data[TP_DIAG_TX_LEN - (UI_8)1];
} * tp_rsa_read_data_by_identifier;
#endif

/**********************************************************************
| Servei:  RequestDownload de RSA
|----------------------------------------------------------------------
| Explicacio dels parametres:
|----------------------------------------------------------------------
| Mida: 1
/--------------------------------------------------------------------*/
typedef struct {
	UI_8 status;
} * tp_rsa_request_download;

typedef struct {
	t_download_status download_status;
	t_device_addressed device_addressed;
	UI_8 download_compression;
	UI_8 download_encrypting;
	t_iso3_addr base_addr;
	t_iso3_addr dest_addr;
	t_iso3_addr last_addr;
	UI_8 block_seq;
	UI_16 block_size;
	t_iso3_addr block_ptr;
}t_download_control;

typedef struct {
	UI_8 local_seed[SECURITY_SEED_SIZE];
	UI_8 host_key[SECURITY_KEY_SIZE];
}t_security_control;

/*--------------------------- variables globals --------------------------*/

/* Answer Control */
extern UI_8 force_response;
extern t_clock timer_s3;
extern t_clock timer_p2;
extern BOOL iso15765_3_supress_pos_resp;
extern UI_8 iso15765_3_current_service;
extern UI_8 pending_response_mode;
extern BOOL pending_response;
extern t_iso15765_3_req_mode iso15765_3_request_mode;

/* Download Control */
extern t_download_control download_control;

/* Security Session Control */
extern t_security_control security_control;

/* Phisical and functional diagnostic config structures */
extern UI_8 diag_phy_rx_buf[TP_DIAG_RX_LEN];
#if (FUN_DIAG_STATUS == FUN_DIAG_DISABLED)
extern UI_8 diag_fun_rx_buf[TP_DIAG_FUN_RX_LEN];
#endif

#ifdef LIN_ISO3
	extern UI_8 diag_tx_buf[TP_DIAG_RX_TX_LEN];
#else
	extern UI_8 diag_tx_buf[TP_DIAG_TX_LEN];
#endif

/*------------------------- prototips de funcions ------------------------*/
/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Functionalities Contract Description:
|  * Rutina d'inicialitzacio del kwp2000.
|---------------------------------------------------------------------------
| Parameters Explanation:
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? CPU cycles | O(n): CTE
| Tmax Int En :   ? CPU cycles | O(n): CTE
| Tmax Total  :   ? CPU cycles | O(n): CTE
/---------------------------------------------------------------------------*/
void InicialitzaIso15765_3Task(void);

/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Functionalities Contract Description:
|  * Tasca principal del kwp2000 que ha de ser cridada de forma periodica en
|    el bucle principal del programa.
|---------------------------------------------------------------------------
| Parameters Explanation:
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? CPU cycles | O(n): CTE
| Tmax Int En :   ? CPU cycles | O(n): CTE
| Tmax Total  :   ? CPU cycles | O(n): CTE
/---------------------------------------------------------------------------*/
void Iso15765_3Task(void);

/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Functionalities Contract Description:
|  * Macro d'acces al buffer de resposta d'una peticio de servei.
|  * El contigut del buffer nomes es valid fins que es retorna del context
|    de la rutina que n'ha obtingut l'acces.
|---------------------------------------------------------------------------
| Parameters Explanation:
|   t_kwp_resp_data: Tipus de dades de la resposta per la cual es vol obtenir
|                    acces al buffer.
|   resultat: variable del tipus de la resposta demanat.
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? CPU cycles | O(n): CTE
| Tmax Int En :   ? CPU cycles | O(n): CTE
| Tmax Total  :   ? CPU cycles | O(n): CTE
/---------------------------------------------------------------------------*/
#define ISO15765_3_GET_RESP_DATA(t_uds_resp_data) ((t_uds_resp_data)&diag_tx_buf[1])

/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Description:
|   Used by the callbacks to increment the size of the positive response
|---------------------------------------------------------------------------
| Arguments:
|   resp_frm_size: NUmber of bytes added to the response buffer
|                  by the callback
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? CPU cycles | O(n): CTE
| Tmax Int En :   ? CPU cycles | O(n): CTE
| Tmax Total  :   ? CPU cycles | O(n): CTE
/---------------------------------------------------------------------------*/
void Iso15765_3IncrementResponseSize(UI_16 resp_frm_size);

/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Description:
|   Used by the callbacks to increment the size of the positive response
|---------------------------------------------------------------------------
| Arguments:
|   resp_frm_size: NUmber of bytes added to the response buffer
|                  by the callback
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? CPU cycles | O(n): CTE
| Tmax Int En :   ? CPU cycles | O(n): CTE
| Tmax Total  :   ? CPU cycles | O(n): CTE
/---------------------------------------------------------------------------*/
UI_16 Iso15765_3GetResponseSize(void);

/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Functionalities Contract Description:
|  * Rutina d'enviament de resposta a una peticio de servei.
|  * Tot servei ha d'acabar amb la crida a aquesta rutina.
|  * Quan s'envia com a resposta ISO16765_3_ERR_RESPONSE_PENDING s'activa
|    l'enviament periodic de respostes negatives amb peticio d'extensio
|    de temps fins que s'envia amb aquesta rutina una altre resposta.
|---------------------------------------------------------------------------
| Parameters Explanation:
|   resp_mode: ISO15765_3_POSITIVE_RESPONSE positive response
|              ISO15765_3_ERR_RESPONSE_PENDING pending response
|              Any other value is considered an error code
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? CPU cycles | O(n): CTE
| Tmax Int En :   ? CPU cycles | O(n): CTE
| Tmax Total  :   ? CPU cycles | O(n): CTE
/---------------------------------------------------------------------------*/
void Iso15765_3SendResponse(UI_8 resp_mode);

/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Functionalities Contract Description:
|  * Rutina de canvi de la sessio activa actual.
|---------------------------------------------------------------------------
| Parameters Explanation:
|   new_session: Valor de la que sera la nova sessio activa
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? CPU cycles | O(n): CTE
| Tmax Int En :   ? CPU cycles | O(n): CTE
| Tmax Total  :   ? CPU cycles | O(n): CTE
/---------------------------------------------------------------------------*/
void Iso15765_3ChangeActiveSession(UI_8 new_session);

/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Functionalities Contract Description:
|  * Funcio de consulta de la sessio activa actual
|---------------------------------------------------------------------------
| Parameters Explanation:
|   resultat: Numero de la sessio activa actual.
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? CPU cycles | O(n): CTE
| Tmax Int En :   ? CPU cycles | O(n): CTE
| Tmax Total  :   ? CPU cycles | O(n): CTE
/---------------------------------------------------------------------------*/
UI_8 Iso15765_3QueryActiveSession(void);

/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Functionalities Contract Description:
|  * Funcio de consulta de la sessio activa actual
|---------------------------------------------------------------------------
| Parameters Explanation:
|   resultat: Numero de la sessio activa actual.
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? CPU cycles | O(n): CTE
| Tmax Int En :   ? CPU cycles | O(n): CTE
| Tmax Total  :   ? CPU cycles | O(n): CTE
/---------------------------------------------------------------------------*/
UI_8 Iso15765_3QueryActiveSessionMask(void);

/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Functionalities Contract Description:
|  * Rutina de canvi del nivell d'acces de seguretat
|---------------------------------------------------------------------------
| Parameters Explanation:
|   new_sec_acc_sts: Nou nivell d'acces de seguretat
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? CPU cycles | O(n): CTE
| Tmax Int En :   ? CPU cycles | O(n): CTE
| Tmax Total  :   ? CPU cycles | O(n): CTE
/---------------------------------------------------------------------------*/
void UdsChangeSecurityAccessStatus(UI_8 new_sec_acc_sts);

/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Functionalities Contract Description:
|  * Funcio de consulta del nivell de seguretat.
|---------------------------------------------------------------------------
| Parameters Explanation:
|   resultat: Valor del nivell d'acces de seguretat actual
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? CPU cycles | O(n): CTE
| Tmax Int En :   ? CPU cycles | O(n): CTE
| Tmax Total  :   ? CPU cycles | O(n): CTE
/---------------------------------------------------------------------------*/
UI_8 UdsSecurityTaskQueryAccessStatus(void);

/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Functionalities Contract Description:
|  * Check if request seed is consecutive or the first request.
|---------------------------------------------------------------------------
| Parameters Explanation:
|   resultat: true if consecutive, false is first
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? CPU cycles | O(n): CTE
| Tmax Int En :   ? CPU cycles | O(n): CTE
| Tmax Total  :   ? CPU cycles | O(n): CTE
/---------------------------------------------------------------------------*/
BOOL UdsSecurityTaskQueryIfConsecutiveRequestSeed(void);

/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Functionalities Contract Description:
|  * Provide the random number for seed generic.
|---------------------------------------------------------------------------
| Parameters Explanation:
|   resultat: random number
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? CPU cycles | O(n): CTE
| Tmax Int En :   ? CPU cycles | O(n): CTE
| Tmax Total  :   ? CPU cycles | O(n): CTE
/---------------------------------------------------------------------------*/
UI_8 UdsSecurityTaskSeedGeneric(void);

/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Functionalities Contract Description:
|  * Funcio de consulta del mode d'adreçament de la peticio de servei actual
|---------------------------------------------------------------------------
| Parameters Explanation:
|  resultat: KWP_PHY_REQUEST si s'ha fet una peticio fisica (punt a punt)
|            KWP_FUN_REQUEST si s'ha fet una peticio funcional (broadcast)
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? CPU cycles | O(n): CTE
| Tmax Int En :   ? CPU cycles | O(n): CTE
| Tmax Total  :   ? CPU cycles | O(n): CTE
/---------------------------------------------------------------------------*/
t_iso15765_3_req_mode Iso15765_3QueryRequestMode(void);

/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Description:
|   Used by any function to know the size of the digan frame
|---------------------------------------------------------------------------
|
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? CPU cycles | O(n): CTE
| Tmax Int En :   ? CPU cycles | O(n): CTE
| Tmax Total  :   ? CPU cycles | O(n): CTE
/---------------------------------------------------------------------------*/
UI_16 Iso15765_3QueryRequestSize( void );

/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Functionalities Contract Description:
|  * Rutina descodificadora del servei requerit en la peticio de servei actual
|---------------------------------------------------------------------------
| Parameters Explanation:
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? CPU cycles | O(n): CTE
| Tmax Int En :   ? CPU cycles | O(n): CTE
| Tmax Total  :   ? CPU cycles | O(n): CTE
/---------------------------------------------------------------------------*/
void Iso15765_3Servicios(void);

/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Description:
|  * Rutina que s'ha de cridar de forma sincrona que desancadena l'enviament
|    de resposta a la capa inferior
|  * Aquesta rutina nomes pot ser cridada de forma sincrona dins la maquina
|    d'estats de capa 3
|---------------------------------------------------------------------------
| Arguments:
|   resp_mode: ISO15765_3_POSITIVE_RESPONSE positive response
|              ISO15765_3_ERR_RESPONSE_PENDING pending response
|              Any other value is considered an error code (neg response)
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? CPU cycles | O(n): CTE
| Tmax Int En :   ? CPU cycles | O(n): CTE
| Tmax Total  :   ? CPU cycles | O(n): CTE
/---------------------------------------------------------------------------*/
void Iso15765_3SendResponseSync(UI_8 resp_mode);

/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Description:
|   * Routine that check if a response has been sent. This routine must be
|     called after sending a response to check when this response has been
|     sent.
|---------------------------------------------------------------------------
| Arguments:
|   * return TRUE if the response has been sent or if a TX problem has been
|     detected. Return FALSE if the response is still pending to be sent.
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? cicles cpu | O(n): CTE 
| Tmax Int En :   ? cicles cpu | O(n): CTE 
| Tmax Total  :   ? cicles cpu | O(n): CTE 
/---------------------------------------------------------------------------*/
BOOL Iso15765_3GetResponseSent(void);

/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Functionalities Contract Description:
|  * Rutina d'atencio al servei Diagnostic Session Control
|  * Aquest servei s'utilitza per gestionar la sessio de diagnostic activa
|  * La seva implementacio es obligatoria
|  * S'ha d'enviar la resposta positiva abans que la nova sessio s'activi
|  * Les diferents rutines i funcions del protocol ISO15765_· que es poden
|    fer servir per implementar aquest servei son:
|    Iso15765_3ChangeActiveSession(...) per canviar la sessio activa 
|    Iso15765_3QueryActiveSession() per consultar la sessio activa actual.
|    Iso_15765_3QuerySecurityAccessStatus() per consultar el nivell de
|                                           seguretat actual.
|---------------------------------------------------------------------------
| Parameters Explanation:
|   session: Nova sessio que es vol que sigui la sessio activa
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? CPU cycles | O(n): CTE 
| Tmax Int En :   ? CPU cycles | O(n): CTE 
| Tmax Total  :   ? CPU cycles | O(n): CTE 
/---------------------------------------------------------------------------*/
#ifdef UDS_SERVICE_SESSION_CONTROL		
void UDServiceSessionCtrl(UI_8 session, UI_8 size);
void Iso15765_3_ForceSessionChange ( UI_8 session, BOOL supress_positive_response );
#endif

/*****************************************************************************
| Portability:  Generica
|----------------------------------------------------------------------------
| Description:
|  * Rutina que recupera la ISO15765_3 en cas que la capa d'aplicacio no 
|    hagi donat resposta durant un timeout de error maxim. Aquesta rutina
|    posara la capa 2 i la capa 3 en estat idle per tornar a acceptar peticions
|    de diagnostic.
|---------------------------------------------------------------------------
| Arguments:
|   resp_mode: ISO15765_3_POSITIVE_RESPONSE positive response
|              ISO15765_3_ERR_RESPONSE_PENDING pending response
|              Any other value is considered an error code (neg response)
|   unblock_iso2: flag that says to ISO15765_2 if has to unblock himself
|                 at the end of this next transmission
|---------------------------------------------------------------------------
| Timing:
| Tmax Int Dis:   ? cicles cpu | O(n): CTE 
| Tmax Int En :   ? cicles cpu | O(n): CTE 
| Tmax Total  :   ? cicles cpu | O(n): CTE 
/---------------------------------------------------------------------------*/
void Iso15765_3AbortResponse(void);

#endif
